======================
The analysis home page
======================

The `analysis home page <https://pesummary.github.io/GW190412/html/IMRPhenomPv3HM_IMRPhenomPv3HM.html>`_
provides the key plots for this analysis. This includes the
`marginalized 1d histograms <mass_1.html>`_ for the masses, spins etc, the
skymap showing the preferred location of the source and a summarytable providing
the maxL, mean, median etc values.

Below each plot, we see a caption button explaining the plot and a command
line button which can be run to generate the same plot. The summary table may
be exported to a `csv` file by clicking the export to CSV button.
